@@ -25,6 +25,6 @@ test_that("cr_fundref fails correctly", {
   skip_on_cran()
   
   library('httr')
-  expect_warning(cr_fundref(dois='10.13039/100000001afasfasdf'), 
+  expect_warning(cr_funders(dois='10.13039/100000001afasfasdf'), 
                "Resource not found")
 })
