@@ -33,8 +33,13 @@ test_that("cr_journals warns correctly", {
   skip_on_cran()
   
   expect_warning(cr_journals(issn=c('blblbl', '1932-6203')), 
-                 regexp = "only data with valid ISSN returned", all = TRUE)
+                 regexp = "Resource not found", all = TRUE)
   expect_equal(NROW(suppressWarnings(cr_journals(issn=c('blblbl', '1932-6203')))), 1)
   expect_is(suppressWarnings(cr_journals(issn=c('blblbl', '1932-6203'))), "tbl_df")
 })
 
+test_that("ISSNs that used to fail badly - should fail better now", {
+  expect_warning(cr_journals("0413-6597"), "Resource not found")
+  expect_warning(cr_journals(c('1932-6203', '1803-2427', "0413-6597")), "Resource not found")
+  expect_equal(NROW(suppressMessages(suppressWarnings(cr_journals(c('1932-6203', '1803-2427', "0413-6597"))))), 2)
+})
