@@ -41,10 +41,10 @@ test_that("cr_members fails correctly", {
   expect_error(cr_members(config=timeout(0.01)))
   expect_equal(NROW(cr_members(query = "adfaaf")$data), 0)
   
-  expect_warning(cr_members(member_ids=c(323234343434,3434343434), works=TRUE, facet=TRUE), 
-                 "Server error - check your query")
+  expect_warning(cr_members(member_ids=c(323234343434, 3434343434), works=TRUE, facet=TRUE), 
+                 "java.lang.NumberFormatException:")
   expect_warning(cr_members(member_ids=c(323234343434,3434343434,98), works=TRUE, facet=TRUE), 
-                 "Server error - check your query")
+                 "java.lang.NumberFormatException:")
   
   # fails due to facet not supported
   expect_warning(cr_members(facet = TRUE), 
